<?php
/* --------------------------------------------------------------
   StaticSeoUrlServiceFactory.inc.php 2017-05-24
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class StaticSeoUrlServiceFactory
 *
 * @category   System
 * @package    StaticSeoUrl
 * @subpackage Factories
 */
class StaticSeoUrlServiceFactory extends AbstractStaticSeoUrlServiceFactory
{
	/**
	 * Database connection.
	 *
	 * @var CI_DB_query_builder
	 */
	protected $db;
	
	
	/**
	 * StaticSeoUrlServiceFactory constructor.
	 *
	 * @param CI_DB_query_builder $db Database connection.
	 */
	public function __construct(CI_DB_query_builder $db)
	{
		$this->db = $db;
	}
	
	
	/**
	 * Creates a static seo url read service.
	 *
	 * @return StaticSeoUrlReadServiceInterface
	 */
	public function createStaticSeoUrlReadService()
	{
		$staticSeoUrlRepository        = $this->_getStaticSeoUrlRepository();
		$staticSeoUrlContentRepository = $this->_getStaticSeoUrlContentRepository();
		
		return MainFactory::create('StaticSeoUrlReadService', $staticSeoUrlRepository, $staticSeoUrlContentRepository);
	}
	
	
	/**
	 * Creates a static seo url write service.
	 *
	 * @return StaticSeoUrlWriteServiceInterface
	 */
	public function createStaticSeoUrlWriteService()
	{
		$staticSeoUrlRepository        = $this->_getStaticSeoUrlRepository();
		$staticSeoUrlContentRepository = $this->_getStaticSeoUrlContentRepository();
		
		return MainFactory::create('StaticSeoUrlWriteService', $staticSeoUrlRepository, $staticSeoUrlContentRepository);
	}
	
	
	/**
	 * Creates a static seo url repository instance.
	 *
	 * @return StaticSeoUrlRepositoryInterface
	 */
	protected function _getStaticSeoUrlRepository()
	{
		$staticSeoUrlRepositoryWriter  = MainFactory::create('StaticSeoUrlRepositoryWriter', $this->db);
		$staticSeoUrlRepositoryReader  = MainFactory::create('StaticSeoUrlRepositoryReader', $this->db);
		$staticSeoUrlRepositoryDeleter = MainFactory::create('StaticSeoUrlRepositoryDeleter', $this->db);
		$staticSeoUrlContentRepository = $this->_getStaticSeoUrlContentRepository();
		
		$staticSeoUrlRepository = MainFactory::create('StaticSeoUrlRepository', $staticSeoUrlRepositoryWriter,
		                                              $staticSeoUrlRepositoryReader, $staticSeoUrlRepositoryDeleter,
		                                              $staticSeoUrlContentRepository);
		
		return $staticSeoUrlRepository;
	}
	
	
	/**
	 * Creates a static seo url repository instance.
	 *
	 * @return StaticSeoUrlContentRepositoryInterface
	 */
	protected function _getStaticSeoUrlContentRepository()
	{
		$staticSeoUrlContentRepositoryWriter  = MainFactory::create('StaticSeoUrlContentRepositoryWriter', $this->db);
		$staticSeoUrlContentRepositoryReader  = MainFactory::create('StaticSeoUrlContentRepositoryReader', $this->db);
		$staticSeoUrlContentRepositoryDeleter = MainFactory::create('StaticSeoUrlContentRepositoryDeleter', $this->db);
		
		$staticSeoUrlContentRepository = MainFactory::create('StaticSeoUrlContentRepository',
		                                                     $staticSeoUrlContentRepositoryWriter,
		                                                     $staticSeoUrlContentRepositoryReader,
		                                                     $staticSeoUrlContentRepositoryDeleter);
		
		return $staticSeoUrlContentRepository;
	}
}