<?php

/* --------------------------------------------------------------
  AbstractVersionInfoReader.inc.php 2017-05-12
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2017 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
*/

/**
 * Class AbstractVersionInfoReader
 *
 * @category    System
 * @package     VersionInfo
 * @subpackage  Reader
 */
abstract class AbstractVersionInfoReader
{
	/**
	 * Determines the name of the version info items while considering known edge cases.
	 *
	 * @param NonEmptyStringType $versionInfoItemName
	 *
	 * @return string $versionInfoItemName
	 */
	protected function _determineName(NonEmptyStringType $versionInfoItemName)
	{
		$versionInfoItemName = $versionInfoItemName->asString();
		
		$versionInfoItemName = str_replace('_', '.', $versionInfoItemName);
		
		switch($versionInfoItemName)
		{
			case strpos($versionInfoItemName, 'update-') !== false:
				$versionInfoItemName = 'GX ' . ucwords(substr($versionInfoItemName, 0, strpos($versionInfoItemName, '-',
				                                                                              strpos($versionInfoItemName,
				                                                                                     '-') + 1)));
				break;
			case strpos($versionInfoItemName, 'sp-') !== false:
				$versionInfoItemName = 'GX Service Pack';
				break;
			case strpos($versionInfoItemName, 'mu-') !== false:
				$versionInfoItemName = 'GX Master Update';
				break;
			case strpos($versionInfoItemName, 'ku-') !== false:
				$versionInfoItemName = 'GX Kumulatives Update';
				break;
			case strpos($versionInfoItemName, 'mobile.template') !== false:
				$versionInfoItemName = str_replace('.', ' ', $versionInfoItemName);
				$versionInfoItemName = ucwords(substr($versionInfoItemName, 0, strpos($versionInfoItemName, '-')));
				break;
			case strpos($versionInfoItemName, 'BETA') !== false:
				$versionInfoItemName = 'GX Beta';
				break;
			case is_numeric(str_replace('.', '', $versionInfoItemName)) !== false:
				$versionInfoItemName = 'GX ' . $versionInfoItemName;
				break;
			case strpos($versionInfoItemName, 'MobileCandy') !== false:
				$versionInfoItemName = substr($versionInfoItemName, 0, strpos($versionInfoItemName, 'v'));
				break;
		}
		
		return $versionInfoItemName;
	}
	
	
	/**
	 * Determines the changelog url of the version info items while considering known edge cases.
	 *
	 * @param NonEmptyStringType $versionInfoItemVersion
	 * @param NonEmptyStringType $versionInfoItemVendor
	 * @param NonEmptyStringType $versionInfoItemName
	 *
	 * @return string $changelogVersionURL
	 */
	protected function _determineChangelogURL(NonEmptyStringType $versionInfoItemVersion,
	                                          NonEmptyStringType $versionInfoItemVendor,
	                                          NonEmptyStringType $versionInfoItemName)
	{
		$changelogBaseURL = 'https://developers.gambio.de/changelog/?show=';
		
		$versionInfoItemVersionString = strtolower($versionInfoItemVersion->asString());
		$versionInfoItemVendorString  = $versionInfoItemVendor->asString();
		$versionInfoItemNameString    = $versionInfoItemName->asString();
		
		$changelogVersionURL = $versionInfoItemVersionString;
		
		if($versionInfoItemVendorString !== 'Gambio' || strpos($versionInfoItemNameString, 'Mobile') !== false
		   || strpos($changelogVersionURL, 'unknown_version') !== false
		)
		{
			$changelogBaseURL    = '/';
			$changelogVersionURL = '';
		}
		elseif(strpos($changelogVersionURL, '(') !== false
		       || strpos($changelogVersionURL, 'master update') !== false
		)
		{
			$changelogVersionURL = str_replace(['(', ')', 'master update'], '', $changelogVersionURL);
			if(strpos($changelogVersionURL, ' r') !== false)
			{
				$changelogVersionURL = substr($changelogVersionURL, 0, strpos($changelogVersionURL, 'r'));
			}
		}
		elseif(strpos($changelogVersionURL, ' r') !== false)
		{
			$changelogVersionURL = substr($changelogVersionURL, 0, strpos($changelogVersionURL, 'r'));
		}
		
		if($changelogVersionURL !== '')
		{
			$versionCompare = explode('.', $changelogVersionURL);
			
			if($versionCompare[0] < 2
			   || ($versionCompare[0] < 2 && $versionCompare[1] === 0
			       && $versionCompare[2] < 11)
			)
			{
				$changelogBaseURL    = '/';
				$changelogVersionURL = '';
			}
			elseif($versionCompare[3] < 1)
			{
				$changelogBaseURL = 'https://developers.gambio.de/changelog/';
				
				if(strpos($changelogVersionURL, 'beta') !== false)
				{
					$changelogStartVersionURL = substr($changelogVersionURL, 0, strpos($changelogVersionURL, 'b'));
				}
				else
				{
					$changelogStartVersionURL = $changelogVersionURL;
				}
				
				$changelogVersionURL = '?start=' . $changelogStartVersionURL . 'beta1' . '&stop='
				                       . $changelogVersionURL;
			}
			
			$changelogVersionURL = str_replace(' ', '', $changelogVersionURL);
		}
		
		return $changelogBaseURL . $changelogVersionURL;
	}
}