<?php
/* --------------------------------------------------------------
	SeoTagsHeaderExtender.inc.php 2017-06-02
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
	--------------------------------------------------------------
*/

class SeoTagsHeaderExtender extends SeoTagsHeaderExtender_parent
{
	public function proceed()
	{
		parent::proceed();
		
		$seoBoost     = MainFactory::create_object('GMSEOBoost', [], true);
		$languageCode = new LanguageCode(new StringType(strtoupper($_SESSION['language_code'])));
		$url          = '';
		$html         = '';
		$robots       = 'index,follow';
		
		$baseUrl           = (ENABLE_SSL ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG;
		$requestUri        = gm_get_env_info('REQUEST_URI');
		$trimmedRequestUri = preg_replace('/^\//', '', preg_replace('/^' . strtolower($languageCode) . '/', '',
		                                                            str_replace(DIR_WS_CATALOG, '', $requestUri)));
		$getParams         = parse_url($requestUri, PHP_URL_QUERY);
		parse_str($getParams, $getArray);
		$getArray = array_keys($getArray);
		
		$languageProvider = MainFactory::create('LanguageProvider', StaticGXCoreLoader::getDatabaseQueryBuilder());
		$activeCodes      = $languageProvider->getActiveCodes();
		$defaultLangCode  = $languageProvider->getDefaultLanguageCode();
		
		$noIndexKeys = array(
			'feature_categories_id',
			'filter_categories_id',
			'filter_fv_id',
			'filter_id',
			'filter_price_max',
			'filter_price_min',
			'keywords',
			'listing_count',
			'listing_sort',
			'page',
			'value_conjunction'
		);
		
		$noRelPrevNext = array(
			'feature_categories_id',
			'filter_categories_id',
			'filter_fv_id',
			'filter_id',
			'filter_price_max',
			'filter_price_min',
			'listing_count',
			'listing_sort',
			'value_conjunction'
		);
		
		foreach($noIndexKeys as $key)
		{
			if(in_array($key, $getArray))
			{
				$robots = 'noindex,follow';
				break;
			}
		}
		
		if(isset($GLOBALS['actual_products_id']) && !empty($GLOBALS['actual_products_id']))
		{
			/** @var ProductReadService $productReadService */
			$productReadService = StaticGXCoreLoader::getService('ProductRead');
			$product            = $productReadService->getProductById(new IdType((int)$GLOBALS['actual_products_id']));
			
			if($seoBoost->boost_products)
			{
				$altUrl = $seoBoost->get_boosted_product_url($GLOBALS['actual_products_id']);
				
				if(substr($altUrl, 2, 1) === '/')
				{
					$altUrl = substr($altUrl, 3);
				}
				
				if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $altUrl . '" />'
					         . "\n\t\t";
				}
				elseif($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl . '?language=' . strtolower($languageCode)
					         . '" />' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl . '" />' . "\n\t\t";
				}
			}
			else
			{
				try
				{
					$productLinkParams = xtc_product_link($GLOBALS['actual_products_id'], $product->getName($languageCode),
					                                      $product->getUrlKeywords($languageCode),
					                                      $_SESSION['languages_id']);
				}
				catch(InvalidArgumentException $e)
				{
					$productLinkParams = xtc_product_link($GLOBALS['actual_products_id'], '', '',
					                                      $_SESSION['languages_id']);
				}
				
				$url = FILENAME_PRODUCT_INFO . '?' . $productLinkParams;
				
				if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $url . '"/>'
					         . "\n\t\t";
				}
				elseif($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . htmlspecialchars('&language=')
					         . strtolower($languageCode) . '"/>' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . '"/>' . "\n\t\t";
				}
			}
			
			if($robots === 'index,follow' && $activeCodes->count() > 1)
			{
				if(gm_get_conf('GM_SEO_BOOST_PRODUCTS') === 'true')
				{
					if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/'
						         . $altUrl . '"/>' . "\n\t\t";
					}
					else
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $altUrl . '?language='
						         . $defaultLangCode . '"/>' . "\n\t\t";
					}
				}
				elseif(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/' . $url
					         . '"/>' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $url
					         . htmlspecialchars('&language=') . $defaultLangCode . '"/>' . "\n\t\t";
				}
				
				foreach($activeCodes as $code)
				{
					$langCode   = new LanguageCode(new StringType($code->asString()));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					if($seoBoost->boost_products)
					{
						$altUrl = $seoBoost->get_boosted_product_url($GLOBALS['actual_products_id'], '', $languageId);
						
						if(substr($altUrl, 2, 1) === '/')
						{
							$altUrl = substr($altUrl, 3);
						}
						
						if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
							         . strtolower($code) . '/' . $altUrl . '" />' . "\n\t\t";
						}
						else
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
							         . $altUrl . '?language=' . strtolower($code) . '" />' . "\n\t\t";
						}
					}
					else
					{
						try
						{
							$productLinkParams = xtc_product_link($GLOBALS['actual_products_id'],
							                                      $product->getName($langCode),
							                                      $product->getUrlKeywords($langCode), $languageId);
						}
						catch(InvalidArgumentException $e)
						{
							continue;
						}
						
						$url = FILENAME_PRODUCT_INFO . '?' . $productLinkParams;
						
						if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
							         . strtolower($code) . '/' . $url . '" />' . "\n\t\t";
						}
						else
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl . $url
							         . htmlspecialchars('&language=') . strtolower($code) . '" />' . "\n\t\t";
						}
					}
				}
			}
		}
		elseif(isset($_GET['cat']) && isset($GLOBALS['current_category_id']) && !empty($GLOBALS['current_category_id']))
		{
			/** @var CategoryReadService $categoryReadService */
			$categoryReadService = StaticGXCoreLoader::getService('CategoryRead');
			$category            = $categoryReadService->getCategoryById(new IdType((int)$GLOBALS['current_category_id']));
			$t_pageParam         = '';
			
			if(isset($_GET['page']) && !empty($_GET['page']) !== '')
			{
				$t_pageParam = 'page=' . $_GET['page'];
			}
			
			if($seoBoost->boost_categories)
			{
				$altUrl = $seoBoost->get_boosted_category_url($GLOBALS['current_category_id']);
				
				if(substr($altUrl, 2, 1) === '/')
				{
					$altUrl = substr($altUrl, 3);
				}
				
				if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $altUrl;
				}
				elseif($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl . '?language=' . strtolower($languageCode);
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl;
				}
				
				if($t_pageParam !== '')
				{
					if(strpos($html, '?') !== false)
					{
						$html .= '&' . $t_pageParam;
					}
					else
					{
						$html .= '?' . $t_pageParam;
					}
				}
				
				$html .= '" />' . "\n\t\t";
			}
			else
			{
				try
				{
					$categoryLinkParams = xtc_category_link($GLOBALS['current_category_id'],
					                                        $category->getName($languageCode),
					                                        $category->getUrlKeywords($languageCode),
					                                        $_SESSION['languages_id']);
				}
				catch(InvalidArgumentException $e)
				{
					$categoryLinkParams = xtc_category_link($GLOBALS['current_category_id'], '', '',
					                                        $_SESSION['languages_id']);
				}
				
				if(isset($_GET['cPath']) && !empty($_GET['cPath']))
				{
					$categoryLinkParams .= '&cPath=' . $_GET['cPath'];
				}
				
				if($t_pageParam !== '')
				{
					$categoryLinkParams .= '&' . $t_pageParam;
				}
				
				$url = htmlspecialchars(FILENAME_DEFAULT . '?' . $categoryLinkParams);
				
				if($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . htmlspecialchars('&language=')
					         . strtolower($languageCode) . '"/>' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . '"/>' . "\n\t\t";
				}
			}
			
			if($activeCodes->count() > 1)
			{
				if(gm_get_conf('GM_SEO_BOOST_CATEGORIES') === 'true')
				{
					$langCode   = new LanguageCode(new StringType($defaultLangCode));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					$altUrl = $seoBoost->get_boosted_category_url($GLOBALS['current_category_id'], $languageId);
					
					if(substr($altUrl, 2, 1) === '/')
					{
						$altUrl = substr($altUrl, 3);
					}
					
					if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/'
						         . $altUrl . '"/>' . "\n\t\t";
					}
					else
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $altUrl . '?language='
						         . strtolower($languageCode) . '"/>' . "\n\t\t";
					}
				}
				else
				{
					$langCode   = new LanguageCode(new StringType($defaultLangCode));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					try
					{
						$categoryLinkParams = xtc_category_link($GLOBALS['actual_products_id'],
						                                        $category->getName($langCode),
						                                        $category->getUrlKeywords($langCode), $languageId);
					}
					catch(InvalidArgumentException $e)
					{
						//just go on
					}
					
					if(isset($_GET['cPath']) && !empty($_GET['cPath']))
					{
						$categoryLinkParams .= '&cPath=' . $_GET['cPath'];
					}
					
					if($t_pageParam !== '')
					{
						$categoryLinkParams .= '&' . $t_pageParam;
					}
					
					$url = FILENAME_DEFAULT . '?' . htmlspecialchars($categoryLinkParams);
					
					if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/'
						         . $url . '"/>' . "\n\t\t";
					}
					else
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $url
						         . htmlspecialchars('&language=') . $defaultLangCode . '"/>' . "\n\t\t";
					}
				}
				
				foreach($activeCodes as $code)
				{
					$langCode   = new LanguageCode(new StringType($code->asString()));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					if($seoBoost->boost_categories)
					{
						$altUrl = $seoBoost->get_boosted_category_url($GLOBALS['current_category_id'], $languageId);
						
						if(substr($altUrl, 2, 1) === '/')
						{
							$altUrl = substr($altUrl, 3);
						}
						
						if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
						{
							$altUrl = $baseUrl . strtolower($langCode) . '/' . $altUrl;
						}
						else
						{
							$altUrl = $baseUrl . $altUrl . '?language=' . strtolower($code);
						}
					}
					else
					{
						try
						{
							$categoryLinkParams = xtc_category_link($GLOBALS['actual_products_id'],
							                                        $category->getName($langCode),
							                                        $category->getUrlKeywords($langCode), $languageId);
						}
						catch(InvalidArgumentException $e)
						{
							continue;
						}
						
						if(isset($_GET['cPath']) && !empty($_GET['cPath']))
						{
							$categoryLinkParams .= '&cPath=' . $_GET['cPath'];
						}
						
						if($t_pageParam !== '')
						{
							$categoryLinkParams .= '&' . $t_pageParam;
						}
						
						if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
						{
							$altUrl = $baseUrl . strtolower($langCode) . '/' . FILENAME_DEFAULT . '?' . $categoryLinkParams;
						}
						else
						{
							$altUrl = $baseUrl . FILENAME_DEFAULT . '?' . htmlspecialchars($categoryLinkParams
							                                                               . '&language=')
							          . strtolower($code);
						}
					}
					
					if($html === '')
					{
						$html .= '<link rel="alternate" hreflang="' . strtolower($languageCode) . '" href="'
						         . htmlspecialchars($url) . '" />' . "\n\t\t";
					}
					
					$html .= '<link rel="alternate" hreflang="' . strtolower($langCode) . '" href="' . $altUrl . '" />'
					         . "\n\t\t";
				}
			}
			
			$relNextPrev = '';
			if(!empty($_SESSION['relPrevUrl']))
			{
				$relNextPrev .= '<link rel="prev" href="' . $_SESSION['relPrevUrl'];
				
				if($activeCodes->count() > 1 && gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') !== 'true')
				{
					if(strpos($_SESSION['relPrevUrl'], '?') !== false)
					{
						$relNextPrev .= htmlspecialchars('&language=') . strtolower($languageCode);
					}
					else
					{
						$relNextPrev .= '?language=' . strtolower($languageCode);
					}
				}
				
				$relNextPrev .= '" />' . "\n\t\t";
			}
			
			if(!empty($_SESSION['relNextUrl']))
			{
				$relNextPrev .= '<link rel="next" href="' . $_SESSION['relNextUrl'];
				
				if($activeCodes->count() > 1 && gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') !== 'true')
				{
					if(strpos($_SESSION['relNextUrl'], '?') !== false)
					{
						$relNextPrev .= htmlspecialchars('&language=') . strtolower($languageCode);
					}
					else
					{
						$relNextPrev .= '?language=' . strtolower($languageCode);
					}
				}
				
				$relNextPrev .= '" />' . "\n\t\t";
			}
			
			foreach($noRelPrevNext as $key)
			{
				if(in_array($key, $getArray))
				{
					$relNextPrev = '';
					break;
				}
			}
			
			$html .= $relNextPrev;
		}
		elseif(isset($_GET['coID']))
		{
			
			$coID = (int)$_GET['coID'];
			
			if($seoBoost->boost_content)
			{
				$contentId = $seoBoost->get_content_id_by_content_group($coID);
				$altUrl    = $seoBoost->get_boosted_content_url($contentId);
				
				if(substr($altUrl, 2, 1) === '/')
				{
					$altUrl = substr($altUrl, 3);
				}
				
				if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $altUrl . '" />'
					         . "\n\t\t";
				}
				elseif($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl . '?language=' . strtolower($languageCode)
					         . '" />' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $altUrl . '" />' . "\n\t\t";
				}
			}
			else
			{
				$url = FILENAME_CONTENT . '?coID=' . $coID;
				
				if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $url . '"/>'
					         . "\n\t\t";
				}
				elseif($activeCodes->count() > 1)
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . htmlspecialchars('&language=')
					         . strtolower($languageCode) . '"/>' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="canonical" href="' . $baseUrl . $url . '"/>' . "\n\t\t";
				}
			}
			
			if($robots === 'index,follow' && $activeCodes->count() > 1)
			{
				if(gm_get_conf('GM_SEO_BOOST_CONTENT') === 'true')
				{
					$langCode   = new LanguageCode(new StringType($defaultLangCode));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					$contentId = $seoBoost->get_content_id_by_content_group($coID, $languageId);
					$altUrl    = $seoBoost->get_boosted_content_url($contentId, $languageId);
					
					if(substr($altUrl, 2, 1) === '/')
					{
						$altUrl = substr($altUrl, 3);
					}
					
					if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/'
						         . $altUrl . '"/>' . "\n\t\t";
					}
					else
					{
						$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $altUrl . '?language='
						         . $defaultLangCode . '"/>' . "\n\t\t";
					}
				}
				elseif(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
				{
					$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $defaultLangCode . '/' . $url
					         . '"/>' . "\n\t\t";
				}
				else
				{
					$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $url
					         . htmlspecialchars('&language=') . $defaultLangCode . '"/>' . "\n\t\t";
				}
				
				foreach($activeCodes as $code)
				{
					$langCode   = new LanguageCode(new StringType($code->asString()));
					$languageId = $languageProvider->getIdByCode($langCode);
					
					if($seoBoost->boost_content)
					{
						$contentId = $seoBoost->get_content_id_by_content_group($coID, $languageId);
						$altUrl    = $seoBoost->get_boosted_content_url($contentId, $languageId);
						
						if(substr($altUrl, 2, 1) === '/')
						{
							$altUrl = substr($altUrl, 3);
						}
						
						if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
							         . strtolower($code) . '/' . $altUrl . '" />' . "\n\t\t";
						}
						else
						{
							$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
							         . $altUrl . '?language=' . strtolower($code) . '" />' . "\n\t\t";
						}
					}
					elseif(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
					{
						$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl
						         . strtolower($code) . '/' . $url . '" />' . "\n\t\t";
					}
					else
					{
						$html .= '<link rel="alternate" hreflang="' . strtolower($code) . '" href="' . $baseUrl . $url
						         . htmlspecialchars('&language=') . strtolower($code) . '" />' . "\n\t\t";
					}
				}
			}
		}
		
		elseif(strpos(strtolower(gm_get_env_info("PHP_SELF")), 'index.php') !== false)
		{
			$t_index = '';
			
			if(gm_get_conf('SUPPRESS_INDEX_IN_URL') !== 'true')
			{
				$t_index .= 'index.php';
			}
			
			if(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
			{
				$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $t_index . '" />'
				         . "\n\t\t";
				
				$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . strtolower($defaultLangCode) . '/'
				         . $t_index . '" />' . "\n\t\t";
				
				foreach($activeCodes as $code)
				{
					$html .= '<link rel="alternate" hreflang="' . strtolower($code->asString()) . '" href="' . $baseUrl
					         . strtolower($code->asString()) . '/' . $t_index . '" />' . "\n\t\t";
				}
			}
			else
			{
				$html .= '<link rel="canonical" href="' . $baseUrl . $t_index . '?language=' . strtolower($languageCode)
				         . '" />' . "\n\t\t";
				
				$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $t_index . '?language='
				         . strtolower($defaultLangCode) . '" />' . "\n\t\t";
				
				foreach($activeCodes as $code)
				{
					$html .= '<link rel="alternate" hreflang="' . strtolower($code->asString()) . '" href="' . $baseUrl
					         . $t_index . '?language=' . strtolower($code->asString()) . '" />' . "\n\t\t";
				}
			}
		}
		elseif(gm_get_conf('USE_SEO_BOOST_LANGUAGE_CODE') === 'true')
		{
			$html .= '<link rel="canonical" href="' . $baseUrl . strtolower($languageCode) . '/' . $trimmedRequestUri
			         . '" />' . "\n\t\t";
			
			$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . strtolower($defaultLangCode) . '/'
			         . $trimmedRequestUri . '" />' . "\n\t\t";
			
			foreach($activeCodes as $code)
			{
				$html .= '<link rel="alternate" hreflang="' . strtolower($code->asString()) . '" href="' . $baseUrl
				         . strtolower($code) . '/' . $trimmedRequestUri . '" />' . "\n\t\t";
			}
		}
		else
		{
			$html .= '<link rel="canonical" href="' . $baseUrl . $trimmedRequestUri . '?language='
			         . strtolower($languageCode) . '" />' . "\n\t\t";
			
			$html .= '<link rel="alternate" hreflang="x-default" href="' . $baseUrl . $trimmedRequestUri . '?language='
			         . $defaultLangCode . '">' . "\n\t\t";
			
			foreach($activeCodes as $code)
			{
				$html .= '<link rel="alternate" hreflang="' . strtolower($code->asString()) . '" href="' . $baseUrl
				         . $trimmedRequestUri . '?language=' . strtolower($code->asString()) . '">' . "\n\t\t";
			}
		}
		
		$html = '<meta name="robots" content="' . $robots . '" />' . "\n\t\t" . $html;
		
		$this->v_output_buffer[] = $html;
	}
}